@@ -1,6 +1,6 @@
 <?php
 // don't ever call this file directly!
-if( strpos( $_SERVER["REQUEST_URI"], 'index-install.php' ) ) {
+if ( strpos( $_SERVER[ "REQUEST_URI" ], 'index-install.php' ) || strpos( $_SERVER[ "SCRIPT_NAME" ], 'index-install.php' ) ) {
 	header( "Location: index.php" );
 	exit();
 }
@@ -10,6 +10,7 @@ if( $_SERVER[ 'HTTP_HOST' ] == 'localhost' ) {
 }
 
 define('WP_INSTALLING', true);
+define('WP_FIRST_INSTALL', true);
 
 $dirs = array( dirname(__FILE__), dirname(__FILE__) . "/wp-content/" );
 
@@ -121,7 +122,7 @@ function printheader() {
 			vertical-align: top;
 		}
 
-		.form-table tr {
+		.form-table tr, .blog-address {
 			background: #eaf3fa;
 		}
 
@@ -318,7 +319,7 @@ function step1() {
 	?>
 	<h2>Installing WordPress &micro;</h2>
 	<p><strong>Welcome to WordPress &micro;.</strong> I will help you install this software by asking you a few questions and asking that you change the permissions on a few directories so I can create configuration files and make a directory to store all your uploaded files.</p>
-	<p>If you have installed the single-blog version of WordPress before, please note that the WordPress &micro; installer is different and trying to create the configuration file wp-config.php youself may result in a broken site. It's much easier to use this installer to get the job done.</p>
+	<p>If you have installed the single-blog version of WordPress before, please note that the WordPress &micro; installer is different and trying to create the configuration file wp-config.php yourself may result in a broken site. It's much easier to use this installer to get the job done.</p>
 	
 	<h2>What do I need?</h2>
 	<ul>
@@ -369,9 +370,9 @@ function printstep1form( $dbname = 'wordpress', $uname = 'username', $pwd = 'pas
 		<input type='hidden' name='action' value='step2' />
 		<h2>Blog Addresses</h2>
 		<p>Please choose whether you would like blogs for the WordPress &micro; install to use sub-domains or sub-directories. You can not change this later. We recommend sub-domains.</p>
-		<p>
+		<p class="blog-address">
 			<label><input type='radio' name='vhost' value='yes' <?php if( $vhost == 'yes' ) echo 'checked="checked"'; ?> /> Sub-domains (like <code>blog1.example.com</code>)</label><br />
-			<label><input type='radio' name='vhost' value='no' <?php if( $vhost == 'no' ) echo 'checked="checked"'; ?> /> Sub-directories (like <code>example.com/blog1</code></label>
+			<label><input type='radio' name='vhost' value='no' <?php if( $vhost == 'no' ) echo 'checked="checked"'; ?> /> Sub-directories (like <code>example.com/blog1</code>)</label>
 		</p>
 
 		<h2>Database</h2>
@@ -402,7 +403,8 @@ function printstep1form( $dbname = 'wordpress', $uname = 'username', $pwd = 'pas
 				<th scope='row'>Server Address</th> 
 				<td>
 					<input type='text' name='basedomain' value='<?php echo $hostname ?>' />
-					<br />What is the Internet address of your site? You should enter the shortest address possible. For example, use <em>example.com</em> instead of <em>www.example.com</em> but if you are going to use an address like <em>blogs.example.com</em> then enter that unaltered in the box below.
+					<p>What is the Internet address of your site? You should enter the shortest address possible. For example, use <em>example.com</em> instead of <em>www.example.com</em> but if you are going to use an address like <em>blogs.example.com</em> then enter that unaltered in the box below.</p>
+					<p>Do not use an IP address (like 127.0.0.1) as your server address. Do not use a single word hostname like <q>localhost</q>, use <q>localhost.localdomain</q> instead.</p>
 				</td> 
 			</tr>
 		</table>
@@ -438,7 +440,7 @@ function step2() {
 	$dbhost  = stripslashes($_POST['dbhost']);
 	$vhost   = stripslashes($_POST['vhost' ]);
 	$prefix  = 'wp_'; // Hardcoded
-	
+
 	$base = stripslashes( dirname($_SERVER["SCRIPT_NAME"]) );
 	if( $base != "/")
 		$base .= "/";
@@ -449,8 +451,14 @@ function step2() {
 	define('DB_PASSWORD', $passwrd);
 	define('DB_HOST', $dbhost);
 
-	if (!file_exists('wp-config-sample.php'))
-		die('Sorry, I need a wp-config-sample.php file to work from. Please re-upload this file from your WordPress installation.');
+	if ( !file_exists( 'wp-config-sample.php' ) )
+		die( 'Sorry, I need a wp-config-sample.php file to work from. Please re-upload this file from your WordPress installation.' );
+
+	if ( file_exists( 'wp-config.php' ) )
+		die( 'Sorry, the file wp-config.php already exists. Please delete it and reload this page.' );
+
+	if ( file_exists( '.htaccess' ) )
+		die( 'Sorry, the file .htaccess already exists. Please delete it and reload this page.' );
 
 	$wp_config_file = file('wp-config-sample.php');
 	// We'll fail here if the values are no good.
@@ -482,11 +490,18 @@ function step2() {
 			case '$base = \'BASE\';':
 				fwrite($handle, str_replace('BASE', $base, $line));
 				break;
-			case "define('SECRET_K":
-			case "define('SECRET_S":
-			case "define('LOGGED_I":
+			case "define('DOMAIN_C":
+				$domain = get_clean_basedomain();
+				fwrite($handle, str_replace("current_site_domain", $domain, $line));
+				break;
+			case "define('PATH_CUR":
+				fwrite($handle, str_replace("current_site_path", str_replace( 'index.php', '', $_SERVER[ 'REQUEST_URI' ] ), $line));
+				break;
 			case "define('AUTH_KEY":
+			case "define('AUTH_SAL":
+			case "define('LOGGED_I":
 			case "define('SECURE_A":
+			case "define('NONCE_KE":
 				fwrite($handle, str_replace('put your unique phrase here', md5( mt_rand() ) . md5( mt_rand() ), $line));
 				break;
 			default:
@@ -499,18 +514,24 @@ function step2() {
 	define( 'VHOST', $vhost );
 }
 
-function step3() {
-	global $wpdb, $current_site, $dirs, $wpmu_version;
-	$base = stripslashes( dirname( $_SERVER["SCRIPT_NAME"] ) );
-	if( $base != "/") {
-		$base .= "/";
-	} 
+function get_clean_basedomain() {
+	global $wpdb;
 	$domain =   $wpdb->escape( $_POST[ 'basedomain' ] );
 	$domain = str_replace( 'http://', '', $domain );
 	if( substr( $domain, 0, 4 ) == 'www.' )
 		$domain = substr( $domain, 4 );
 	if( strpos( $domain, '/' ) )
 		$domain = substr( $domain, 0, strpos( $domain, '/' ) );
+	return $domain;
+}
+
+function step3() {
+	global $wpdb, $current_site, $dirs, $wpmu_version, $wp_db_version;
+	$base = stripslashes( dirname( $_SERVER["SCRIPT_NAME"] ) );
+	if( $base != "/") {
+		$base .= "/";
+	} 
+	$domain = get_clean_basedomain();
 	$email = $wpdb->escape( $_POST[ 'email' ] );
 	if( $email == '' )
 		die( 'You must enter an email address!' );
@@ -529,6 +550,7 @@ function step3() {
 	$wpdb->query( "INSERT INTO ".$wpdb->sitemeta." (meta_id, site_id, meta_key, meta_value) VALUES (NULL, 1, 'site_admins', '" . serialize( array( 'admin' ) ) . "' )" );
 	$wpdb->query( "INSERT INTO ".$wpdb->sitemeta." (meta_id, site_id, meta_key, meta_value) VALUES (NULL, 1, 'allowedthemes', '" . serialize( array( 'classic' => 1, 'default' => 1 ) ) . "' )" );
 	$wpdb->query( "INSERT INTO ".$wpdb->sitemeta." (meta_id, site_id, meta_key, meta_value) VALUES (NULL, 1, 'illegal_names', '" . serialize( array(  "www", "web", "root", "admin", "main", "invite", "administrator" ) ) . "' )" );
+	$wpdb->query( "INSERT INTO ".$wpdb->sitemeta." (meta_id, site_id, meta_key, meta_value) VALUES (NULL, 1, 'wpmu_upgrade_site', '{$wp_db_version}')" );
 	$wpdb->query( "INSERT INTO ".$wpdb->sitemeta." (meta_id, site_id, meta_key, meta_value) VALUES (NULL, 1, 'welcome_email', 'Dear User,
 
 Your new SITE_NAME blog has been successfully set up at:
@@ -562,8 +584,7 @@ Thanks!
 	} else {
 		update_blog_option( 1, 'permalink_structure', '/blog/%year%/%monthnum%/%day%/%postname%/');
 	}
-	
-	update_blog_option( 1, 'rewrite_rules', '');
+	update_blog_option( 1, 'rewrite_rules', false );
 	
 	$msg = "Your new WordPress MU site has been created at\nhttp://{$domain}{$base}\n\nLogin details:\nUsername: admin\nPassword: $pass\nLogin: http://{$domain}{$base}wp-login.php\n";
 	wp_mail( $email, "Your new WordPress MU site is ready!", $msg, "From: wordpress@" . $_SERVER[ 'HTTP_HOST' ]  );
@@ -571,8 +592,39 @@ Thanks!
 	<h2>Installation Finished!</h2>
 	<p>Congratulations! <br />Your <a href='http://<?php echo $domain . $base; ?>'>WordPress &micro; site</a> has been configured.</p>
 	<p>You can <a class="button" href='wp-login.php'>log in</a> using the username "admin" and password <?php echo $pass; ?></p>
+
+	<?php
 	
-	<h2>Directory Permissions</h2>
+	if ( $_POST['vhost' ] == 'yes' ) {
+		$vhost_ok = false;
+		$hostname = substr( md5( time() ), 0, 6 ) . '.' . $domain; // Very random hostname!
+		if( include_once( 'wp-includes/http.php' ) ) {
+			$page = wp_remote_get( 'http://' . $hostname, array( 'timeout' => 5, 'httpversion' => '1.1' ) );
+			if( is_object( $page ) && is_wp_error( $page ) ) {
+				foreach ( $page->get_error_messages() as $err )
+					$errstr = $err;
+			} elseif( $page[ 'response' ][ 'code' ] == 200 ) {
+					$vhost_ok = true;	
+			}
+		} else {
+			$fp = fsockopen( $hostname, 80, $errno, $errstr, 5 ); // Very random hostname!
+			if( $fp ) {
+				$vhost_ok = true;
+				fclose( $fp );
+			}
+		}
+		if( !$vhost_ok ) {
+			echo "<h2>Warning! Wildcard DNS may not be configured correctly!</h2>";
+			echo "<p>To use the subdomain feature of WordPress MU you must have a wildcard entry in your dns. The installer attempted to contact a random hostname ($hostname) on your domain but failed. It returned this error message:<br /> <strong>$errstr</strong></p><p>From the README.txt:</p>";
+			echo "<p><blockquote> If you want to host blogs of the form http://blog.domain.tld/ where domain.tld is the domain name of your machine then you must add a wildcard record to your DNS records.<br />
+This usually means adding a '*' hostname record pointing at your webserver in your DNS configuration tool.  Matt has a more detailed <a href='http://ma.tt/2003/10/10/wildcard-dns-and-sub-domains/'>explanation</a> on his blog. If you still have problems, these <a href='http://mu.wordpress.org/forums/tags/wildcard'>forum messages</a> may help.</blockquote></p>";
+			echo "<p>You can still use your site but any subdomain you create may not be accessible. This check is not foolproof so ignore if you know your dns is correct.</p>";
+		}
+	}
+
+	?>
+	
+	<h3>Directory Permissions</h3>
 	<p>Please remember to reset the permissions on the following directories:
 		<ul>
 		<?php
@@ -594,8 +646,10 @@ Thanks!
 			?>
 		</code>
 	</p>
+	<h3>Delete the Installer</h3>
+	<p>Now that you've installed WordPress &micro;, you don't need the installer any more. You can safely delete <em>index-install.php</em> now. It's always a good idea to remove code and scripts you don't need.</p>
 	
-	<h2>Further reading</h2>
+	<h3>Further reading</h3>
 	<p>
 		<ul>
 			<li>If you run into problems, please search the <a href='http://mu.wordpress.org/forums/'>WordPress &micro; Forums</a> where you will most likely find a solution. Please don't post there before searching. It's not polite.</li>
