@@ -11,6 +11,7 @@ if( is_site_admin() == false ) {
     wp_die( __('You do not have permission to access this page.') );
 }
 $id = intval( $_GET['id'] );
+$protocol = is_ssl() ? 'https://' : 'http://';
 
 if ( $_GET['updated'] == 'true' ) {
 	?>
@@ -68,29 +69,29 @@ if ( $_GET['updated'] == 'true' ) {
 switch( $_GET['action'] ) {
 	// Edit blog
 	case "editblog":
-		$options = $wpdb->get_results( "SELECT * FROM {$wpdb->base_prefix}{$id}_options WHERE option_name NOT LIKE 'rss%' AND option_name NOT LIKE '%user_roles'", ARRAY_A );
+		$blog_prefix = $wpdb->get_blog_prefix( $id );
+		$options = $wpdb->get_results( "SELECT * FROM {$blog_prefix}options WHERE option_name NOT LIKE '_transient_rss%' AND option_name NOT LIKE '%user_roles'", ARRAY_A );
 		$details = $wpdb->get_row( "SELECT * FROM {$wpdb->blogs} WHERE blog_id = '{$id}'", ARRAY_A );
-		$editblog_roles = get_blog_option( $id, "{$wpdb->base_prefix}{$id}_user_roles" );
+		$editblog_roles = get_blog_option( $id, "{$blog_prefix}user_roles" );
 		?>
 		<div class="wrap">
-		<h2><?php _e('Edit Blog'); ?> - <a href='http://<?php echo $details['domain'].$details['path']; ?>'><?php echo $details['domain'].$details['path']; ?></a></h2>
+		<h2><?php _e('Edit Blog'); ?> - <a href='http://<?php echo $details['domain'].$details['path']; ?>'>http://<?php echo $details['domain'].$details['path']; ?></a></h2>
 		<form method="post" action="wpmu-edit.php?action=updateblog"> 
 			<?php wp_nonce_field('editblog'); ?>
 			<input type="hidden" name="id" value="<?php echo $id ?>" /> 
-			<table>
-			<tr>
-				<td valign="top">
-					<div class="wrap">
-						<h3><?php _e('Blog info (wp_blogs)'); ?></h3>
-						<table class="form-table">
+			<div class='metabox-holder' style='width:49%;float:left;'>
+			<div id="blogedit_bloginfo" class="postbox " >
+			<h3 class='hndle'><span><?php _e('Blog info (wp_blogs)'); ?></span></h3>
+			<div class="inside">
+				<table class="form-table">
 							<tr class="form-field form-required">
 								<th scope="row"><?php _e('Domain') ?></th> 
 								<td>http://<input name="blog[domain]" type="text" id="domain" value="<?php echo $details['domain'] ?>" size="33" /></td>
 							</tr> 
 							<tr class="form-field form-required">
 								<th scope="row"><?php _e('Path') ?></th> 
-								<td><input name="blog[path]" type="text" id="path" value="<?php echo $details['path'] ?>" size="40" />
-								<br />(<?php _e( 'siteurl and home will be modified too' ); ?>)</td> 
+								<td><input name="blog[path]" type="text" id="path" value="<?php echo $details['path'] ?>" size="40" style='margin-bottom:5px;' />
+								<br /><input type='checkbox' style='width:20px;' name='update_home_url' value='update' <?php if( get_blog_option( $id, 'siteurl' ) == preg_replace('|/+$|', '', 'http://' . $details['domain'] . $details['path']) || get_blog_option( $id, 'home' ) == preg_replace('|/+$|', '', 'http://' . $details['domain'] . $details['path']) ) echo 'checked="checked"'; ?> /> <?php _e( "Update 'siteurl' and 'home' as well." ); ?></td>
 							</tr> 
 							<tr class="form-field">
 								<th scope="row"><?php _e('Registered') ?></th> 
@@ -103,42 +104,46 @@ switch( $_GET['action'] ) {
 							<tr class="form-field">
 								<th scope="row"><?php _e('Public') ?></th> 
 								<td>
-									<input type='radio' name='blog[public]' value='1' <?php if( $details['public'] == '1' ) echo 'checked="checked"'; ?> /> <?php _e('Yes') ?>
-									<input type='radio' name='blog[public]' value='0' <?php if( $details['public'] == '0' ) echo 'checked="checked"'; ?> /> <?php _e('No') ?>
+									<input type='radio' style='width:20px;' name='blog[public]' value='1' <?php if( $details['public'] == '1' ) echo 'checked="checked"'; ?> /> <?php _e('Yes') ?>
+									<input type='radio' style='width:20px;' name='blog[public]' value='0' <?php if( $details['public'] == '0' ) echo 'checked="checked"'; ?> /> <?php _e('No') ?>
 								</td> 
 							</tr> 
 							<tr class="form-field">
 								<th scope="row"><?php _e( 'Archived' ); ?></th> 
 								<td>
-									<input type='radio' name='blog[archived]' value='1' <?php if( $details['archived'] == '1' ) echo 'checked="checked"'; ?> /> <?php _e('Yes') ?>
-									<input type='radio' name='blog[archived]' value='0' <?php if( $details['archived'] == '0' ) echo 'checked="checked"'; ?> /> <?php _e('No') ?>
+									<input type='radio' style='width:20px;' name='blog[archived]' value='1' <?php if( $details['archived'] == '1' ) echo 'checked="checked"'; ?> /> <?php _e('Yes') ?>
+									<input type='radio' style='width:20px;' name='blog[archived]' value='0' <?php if( $details['archived'] == '0' ) echo 'checked="checked"'; ?> /> <?php _e('No') ?>
 								</td> 
 							</tr> 
 							<tr class="form-field">
 								<th scope="row"><?php _e( 'Mature' ); ?></th> 
 								<td>
-									<input type='radio' name='blog[mature]' value='1' <?php if( $details['mature'] == '1' ) echo 'checked="checked"'; ?> /> <?php _e('Yes') ?>
-									<input type='radio' name='blog[mature]' value='0' <?php if( $details['mature'] == '0' ) echo 'checked="checked"'; ?> /> <?php _e('No') ?>
+									<input type='radio' style='width:20px;' name='blog[mature]' value='1' <?php if( $details['mature'] == '1' ) echo 'checked="checked"'; ?> /> <?php _e('Yes') ?>
+									<input type='radio' style='width:20px;' name='blog[mature]' value='0' <?php if( $details['mature'] == '0' ) echo 'checked="checked"'; ?> /> <?php _e('No') ?>
 								</td> 
 							</tr> 
 							<tr class="form-field">
 								<th scope="row"><?php _e( 'Spam' ); ?></th> 
 								<td>
-									<input type='radio' name='blog[spam]' value='1' <?php if( $details['spam'] == '1' ) echo 'checked="checked"'; ?> /> <?php _e('Yes') ?>
-									<input type='radio' name='blog[spam]' value='0' <?php if( $details['spam'] == '0' ) echo 'checked="checked"'; ?> /> <?php _e('No') ?>
+									<input type='radio' style='width:20px;' name='blog[spam]' value='1' <?php if( $details['spam'] == '1' ) echo 'checked="checked"'; ?> /> <?php _e('Yes') ?>
+									<input type='radio' style='width:20px;' name='blog[spam]' value='0' <?php if( $details['spam'] == '0' ) echo 'checked="checked"'; ?> /> <?php _e('No') ?>
 								</td> 
 							</tr> 
 							<tr class="form-field">
 								<th scope="row"><?php _e( 'Deleted' ); ?></th> 
 								<td>
-									<input type='radio' name='blog[deleted]' value='1' <?php if( $details['deleted'] == '1' ) echo 'checked="checked"'; ?> /> <?php _e('Yes') ?>
-									<input type='radio' name='blog[deleted]' value='0' <?php if( $details['deleted'] == '0' ) echo 'checked="checked"'; ?> /> <?php _e('No') ?>
+									<input type='radio' style='width:20px;' name='blog[deleted]' value='1' <?php if( $details['deleted'] == '1' ) echo 'checked="checked"'; ?> /> <?php _e('Yes') ?>
+									<input type='radio' style='width:20px;' name='blog[deleted]' value='0' <?php if( $details['deleted'] == '0' ) echo 'checked="checked"'; ?> /> <?php _e('No') ?>
 								</td> 
 							</tr> 
 						</table>
-
-						<h3><?php printf( __('Blog options (wp_%s_options)'), $id ); ?></h3>
-						<table class="form-table">
+						<p class="submit" style="margin:-15px 0 -5px 230px;"><input type="submit" name="Submit" value="<?php _e('Update Options &raquo;') ?>" /></p>
+			</div></div>
+			
+			<div id="blogedit_blogoptions" class="postbox " >
+			<h3 class='hndle'><span><?php printf( __('Blog options (wp_%s_options)'), $id ); ?></span></h3>
+			<div class="inside">
+				<table class="form-table">
 							<?php
 							$editblog_default_role = 'subscriber';
 							foreach ( $options as $key => $val ) {
@@ -172,12 +177,12 @@ switch( $_GET['action'] ) {
 							} // End foreach
 							?>
 						</table>
-						<p class="submit">
-							<input type="submit" name="Submit" value="<?php _e('Update Options &raquo;') ?>" /></p>
-					</div>
-				</td>
-				<td valign="top">
-					<?php
+						<p class="submit" style="margin:-15px 0 -5px 230px;"><input type="submit" name="Submit" value="<?php _e('Update Options &raquo;') ?>" /></p>
+			</div></div>
+			</div>
+			
+			<div class='metabox-holder' style='width:49%;float:right;'>
+			<?php
 					// Blog Themes
 					$themes = get_themes();
 					$blog_allowed_themes = wpmu_get_blog_allowedthemes( $id );
@@ -192,24 +197,29 @@ switch( $_GET['action'] ) {
 							$checked = ( isset($blog_allowed_themes[ $theme_key ]) ) ? 'checked="checked"' : '';
 							$out .= '<tr class="form-field form-required">
 									<th title="'.htmlspecialchars( $theme["Description"] ).'" scope="row">'.$key.'</th> 
-									<td><input name="theme['.$theme_key.']" type="checkbox" value="on" '.$checked.'/></td> 
+									<td><input name="theme['.$theme_key.']" type="checkbox" style="width:20px;" value="on" '.$checked.'/>' . __( 'Active' ) . '</td> 
 								</tr>';
 						}
 					}
-
-
-					if( $out != '' ) {
-						echo "<h3>" . __('Blog Themes') . "</h3>";
-						echo '<table class="form-table">';
-							echo '<tr class=""><th>' . __('Theme') . '</th><th>' . __('Enable') . '</th></tr>';
-							echo $out;
-						echo "</table>";
-					}
-
+					
+					if ( $out != '' ) {
+			?>
+			<div id="blogedit_blogthemes" class="postbox">
+			<h3 class='hndle'><span><?php _e('Blog Themes'); ?></span></h3>
+			<div class="inside">
+				<table class="form-table">
+					<tr><th style="font-weight:bold;"><?php _e('Theme'); ?></th></tr>
+					<?php echo $out; ?>
+				</table>
+				<p class="submit" style="margin:-15px 0 -5px 230px;"><input type="submit" name="Submit" value="<?php _e('Update Options &raquo;') ?>" /></p>
+			</div></div>
+			<?php } ?>
+			
+			<?php
 					// Blog users
 					$blogusers = get_users_of_blog( $id );
-					echo '<h3>' . __('Blog Users') . '</h3>';
 					if( is_array( $blogusers ) ) {
+						echo '<div id="blogedit_blogusers" class="postbox"><h3 class="hndle"><span>' . __('Blog Users') . '</span></h3><div class="inside">';
 						echo '<table class="form-table">';
 						echo "<tr><th>" . __('User') . "</th><th>" . __('Role') . "</th><th>" . __('Password') . "</th><th>" . __('Remove') . "</th></tr>";
 						reset($blogusers);
@@ -243,12 +253,16 @@ switch( $_GET['action'] ) {
 							echo '</tr>';
 						}
 						echo "</table>";
+						echo '<p class="submit" style="margin:-15px 0 -5px 230px;"><input type="submit" name="Submit" value="' . __('Update Options &raquo;') . '" /></p>';
+						echo "</div></div>";
 					}
-
-					// New blog user
-					echo "<h3>" . __('Add a new user') . "</h3>"; ?>
-					<p><?php _e('As you type WordPress will offer you a choice of usernames.<br /> Click them to select and hit <em>Update Options</em> to add the user.') ?></p>
-					<table class="form-table">
+			?>
+			
+			<div id="blogedit_blogadduser" class="postbox">
+			<h3 class='hndle'><span><?php _e('Add a new user'); ?></span></h3>
+			<div class="inside">
+				<p style="margin:10px 0 0px;padding:0px 10px 10px;border-bottom:1px solid #DFDFDF;"><?php _e('Enter the username of an existing user and hit <em>Update Options</em> to add the user.') ?></p>
+				<table class="form-table">
 						<tr>
 							<th scope="row"><?php _e('User&nbsp;Login:') ?></th>
 							<td><input type="text" name="newuser" id="newuser" /></td>
@@ -269,17 +283,21 @@ switch( $_GET['action'] ) {
 							</td>
 						</tr>
 					</table>
-
-					<h3><?php _e('Misc Blog Actions') ?></h3>
-					<table class="form-table">
+				<p class="submit" style="margin:-15px 0 -5px 230px;"><input type="submit" name="Submit" value="<?php _e('Update Options &raquo;') ?>" /></p>
+			</div></div>
+			
+			<div id="blogedit_miscoptions" class="postbox">
+			<h3 class='hndle'><span><?php _e('Misc Blog Actions') ?></span></h3>
+			<div class="inside">
+				<table class="form-table">
 						<?php do_action( 'wpmueditblogaction', $id ); ?>
 					</table>
-
-					<p class="submit">
-						<input type="submit" name="Submit" value="<?php _e('Update Options &raquo;') ?>" /></p>
-				</td>
-			</tr>
-			</table>
+				<p class="submit" style="margin:-15px 0 -5px 230px;"><input type="submit" name="Submit" value="<?php _e('Update Options &raquo;') ?>" /></p>
+			</div></div>
+			
+			</div>
+			
+			<div style="clear:both;"></div>
 		</form>
 		</div>
 		<?php
@@ -331,11 +349,11 @@ switch( $_GET['action'] ) {
 		$blog_list = $wpdb->get_results( $query, ARRAY_A );
 
 		// Pagination
-		$url2 = "&order=" . $_GET['order'] . "&amp;sortby=" . $_GET['sortby'] . "&amp;s=";
+		$url2 = "&amp;order=" . $_GET['order'] . "&amp;sortby=" . $_GET['sortby'] . "&amp;s=";
 		if( $_GET[ 'blog_ip' ] ) {
-			$url2 .= "&ip_address=" . urlencode( $s );
+			$url2 .= "&amp;ip_address=" . urlencode( $s );
 		} else {
-			$url2 .= $s . "&ip_address=" . urlencode( $s );
+			$url2 .= $s . "&amp;ip_address=" . urlencode( $s );
 		}
 		$blog_navigation = paginate_links( array(
 			'base' => add_query_arg( 'apage', '%#%' ).$url2,
@@ -384,19 +402,14 @@ switch( $_GET['action'] ) {
 			'blogname'     => $blogname_columns,
 			'lastupdated'  => __('Last Updated'),
 			'registered'   => __('Registered'),
-			'users'        => __('Users'),
-			'plugins'      => __('Actions')
+			'users'        => __('Users')
 		);
+		
+		if( has_filter( 'wpmublogsaction' ) )
+			$posts_columns['plugins'] = __('Actions');
+			
 		$posts_columns = apply_filters('wpmu_blogs_columns', $posts_columns);
 
-		// you can not edit these at the moment
-		$posts_columns['control_edit']      = '';
-		$posts_columns['control_backend']   = '';
-		$posts_columns['control_deactivate']= '';
-		$posts_columns['control_archive']   = '';
-		$posts_columns['control_spam']   	= '';
-		$posts_columns['control_delete']    = '';
-
 		$sortby_url = "s=";
 		if( $_GET[ 'blog_ip' ] ) {
 			$sortby_url .= "&ip_address=" . urlencode( $s );
@@ -454,7 +467,38 @@ switch( $_GET['action'] ) {
  
 							case 'blogname': ?>
 								<td valign="top">
-									<a href="http://<?php echo $blog['domain']. $blog['path']; ?>" rel="permalink"><?php echo $blogname; ?></a>
+									<a href="wpmu-blogs.php?action=editblog&amp;id=<?php echo $blog['blog_id'] ?>" class="edit"><?php echo $blogname; ?></a>
+									<br/>
+									<?php
+									$controlActions	= array();
+									$controlActions[]	= '<a href="wpmu-blogs.php?action=editblog&amp;id=' . $blog['blog_id'] . '" class="edit">' . __('Edit') . '</a>';
+									$controlActions[]	= "<a href='{$protocol}{$blog['domain']}{$blog['path']}wp-admin/' class='edit'>" . __('Backend') . '</a>';
+									
+									if( get_blog_status( $blog['blog_id'], "deleted" ) == '1' )
+										$controlActions[]	= '<a class="delete" href="wpmu-edit.php?action=confirm&amp;action2=activateblog&amp;ref=' . urlencode( $_SERVER['REQUEST_URI'] ) . '&amp;id=' . $blog['blog_id'] . '">' . __('Activate') . '</a>';
+									else
+										$controlActions[]	= '<a class="delete" href="wpmu-edit.php?action=confirm&amp;action2=deactivateblog&amp;ref=' . urlencode( $_SERVER['REQUEST_URI'] ) . '&amp;id=' . $blog['blog_id'] . '">' . __('Deactivate') . '</a>';
+									
+									if( get_blog_status( $blog['blog_id'], "archived" ) == '1' )
+										$controlActions[]	= '<a class="delete" href="wpmu-edit.php?action=confirm&amp;action2=unarchiveblog&amp;id=' .  $blog['blog_id'] . '">' . __('Unarchive') . '</a>';
+									else
+										$controlActions[]	= '<a class="delete" href="wpmu-edit.php?action=confirm&amp;action2=archiveblog&amp;id=' . $blog['blog_id'] . '">' . __('Archive') . '</a>';
+									
+									if( get_blog_status( $blog['blog_id'], "spam" ) == '1' )
+										$controlActions[]	= '<a class="delete" href="wpmu-edit.php?action=confirm&amp;action2=unspamblog&amp;id=' . $blog['blog_id'] . '">' . __('Not Spam') . '</a>';
+									else
+										$controlActions[]	= '<a class="delete" href="wpmu-edit.php?action=confirm&amp;action2=spamblog&amp;id=' . $blog['blog_id'] . '">' . __("Spam") . '</a>';
+									
+									$controlActions[]	= '<a class="delete" href="wpmu-edit.php?action=confirm&amp;action2=deleteblog&amp;id=' . $blog['blog_id'] . '">' . __("Delete") . '</a>';
+									
+									$controlActions[]	= "<a href='http://{$blog['domain']}{$blog['path']}' rel='permalink'>" . __('Visit') . '</a>';
+									?>
+									
+									<?php if (count($controlActions)) : ?>
+									<div class="row-actions">
+										<?php echo implode(' | ', $controlActions); ?>
+									</div>
+									<?php endif; ?>
 								</td>
 							<?php
 							break;
@@ -476,84 +520,38 @@ switch( $_GET['action'] ) {
 								<td valign="top">
 									<?php
 									$blogusers = get_users_of_blog( $blog['blog_id'] ); 
-									if( is_array( $blogusers ) ) {
-										if( $blog['blog_id'] == 1 && count( $blogusers ) > 10 ) {
-											$blogusers = array_slice( $blogusers, 0, 10 );
+									if ( is_array( $blogusers ) ) {
+										$blogusers_warning = '';
+										if ( count( $blogusers ) > 5 ) {
+											$blogusers = array_slice( $blogusers, 0, 5 );
+											$blogusers_warning = __( 'Only showing first 5 users.' ) . ' <a href="' . $protocol . $blog[ 'domain' ] . $blog[ 'path' ] . 'wp-admin/users.php">' . __( 'More' ) . '</a>';
 										}
 										foreach ( $blogusers as $key => $val ) {
 											echo '<a href="user-edit.php?user_id=' . $val->user_id . '">' . $val->user_login . '</a> ('.$val->user_email.')<br />'; 
 										}
+										if( $blogusers_warning != '' ) {
+											echo '<strong>' . $blogusers_warning . '</strong><br />';
+										}
 									}
 									?>
 								</td>
 							<?php
 							break;
-							case 'control_edit': ?>
-								<td valign="top">
-									<?php echo "<a href='wpmu-blogs.php?action=editblog&amp;id=".$blog['blog_id']."' class='edit'>" . __('Edit') . "</a>"; ?>
-								</td>
-							<?php
-							break;
-							case 'control_backend':
-							?>
-								<td valign="top">
-									<?php echo "<a href='http://" . $blog['domain'] . $blog['path'] . "wp-admin/' class='edit'>" . __('Backend') . "</a>"; ?>
-								</td>
-							<?php
-							break;
-
-							case 'control_spam': 
-								if( get_blog_status( $blog['blog_id'], "spam" ) == '1' ) { ?>
-									<td valign="top">
-										<a class='delete' href="wpmu-edit.php?action=confirm&amp;action2=unspamblog&amp;id=<?php echo $blog['blog_id'] ?>&amp;msg=<?php echo urlencode( sprintf( __( "You are about to unspam the blog %s" ), $blogname ) ) ?>"><?php _e("Not Spam") ?></a>
-									</td>
-								<?php } else { ?>
-									<td valign='top'>
-										<a class='delete' href="wpmu-edit.php?action=confirm&amp;action2=spamblog&amp;id=<?php echo $blog['blog_id'] ?>&amp;msg=<?php echo urlencode( sprintf( __( "You are about to mark the blog %s as spam" ), $blogname ) ) ?>""><?php _e("Spam") ?></a>
-									</td>
-								<?php }
-							break;
-
-							case 'control_deactivate':
-								if( get_blog_status( $blog['blog_id'], "deleted" ) == '1' ) { ?>
-									<td valign="top">
-										<a class='delete' href="wpmu-edit.php?action=confirm&amp;action2=activateblog&amp;ref=<?php echo urlencode( $_SERVER['REQUEST_URI'] ) ?>&amp;id=<?php echo $blog['blog_id'] ?>&amp;msg=<?php echo urlencode( sprintf( __( "You are about to activate the blog %s" ), $blogname ) ) ?>"><?php _e("Activate") ?></a>
-									</td>
-								<?php } else { ?>
-									<td valign="top">
-										<a class='delete' href="wpmu-edit.php?action=confirm&amp;action2=deactivateblog&amp;ref=<?php echo urlencode( $_SERVER['REQUEST_URI'] ) ?>&amp;id=<?php echo $blog['blog_id'] ?>&amp;msg=<?php echo urlencode( sprintf( __( "You are about to deactivate the blog %s" ), $blogname ) ) ?>"><?php _e("Deactivate") ?></a>
-									</td>
-								<?php }
-							break;
-
-							case 'control_archive':
-								if( get_blog_status( $blog['blog_id'], "archived" ) == '1' ) { ?>
-									<td valign="top">
-										<a class='delete' href="wpmu-edit.php?action=confirm&amp;action2=unarchiveblog&amp;id=<?php echo $blog['blog_id'] ?>&amp;msg=<?php echo urlencode( sprintf( __( "You are about to unarchive the blog %s" ), $blogname ) ) ?>"><?php _e("Unarchive") ?></a>
-									</td>
-								<?php } else { ?>
-									<td valign="top">
-										<a class='delete' href="wpmu-edit.php?action=confirm&amp;action2=archiveblog&amp;id=<?php echo $blog['blog_id'] ?>&amp;msg=<?php echo urlencode( sprintf( __( "You are about to archive the blog %s" ), $blogname ) ) ?>"><?php _e("Archive") ?></a>
-									</td>
-								<?php }
-							break;
-
-							case 'control_delete': ?>
-								<td valign="top">
-									<a class='delete' href="wpmu-edit.php?action=confirm&amp;action2=deleteblog&amp;id=<?php echo $blog['blog_id'] ?>&amp;msg=<?php echo urlencode( sprintf( __( "You are about to delete the blog %s" ), $blogname ) ) ?>"><?php _e("Delete") ?></a>
-								</td>
-							<?php break;
 
 							case 'plugins': ?>
+								<?php if( has_filter( 'wpmublogsaction' ) ) { ?>
 								<td valign="top">
 									<?php do_action( "wpmublogsaction", $blog['blog_id'] ); ?>
 								</td>
+								<?php } ?>
 							<?php break;
  
 							default: ?>
+								<?php if( has_filter( 'manage_blogs_custom_column' ) ) { ?>
 								<td valign="top">
 									<?php do_action('manage_blogs_custom_column', $column_name, $blog['blog_id']); ?>
 								</td>
+								<?php } ?>
 							<?php break;
 						}
 					}
@@ -575,6 +573,7 @@ switch( $_GET['action'] ) {
 		</div>
 
 		<div class="wrap">
+			<a name="form-add-blog"></a>
 			<h2><?php _e('Add Blog') ?></h2>
 			<form method="post" action="wpmu-edit.php?action=addblog">
 				<?php wp_nonce_field('add-blog') ?>
@@ -582,11 +581,13 @@ switch( $_GET['action'] ) {
 					<tr class="form-field form-required">
 						<th style="text-align:center;" scope='row'><?php _e('Blog Address') ?></th>
 						<td>
-						<?php if( constant( "VHOST" ) == 'yes' ) : ?>
-							<input name="blog[domain]" type="text" title="<?php _e('Domain') ?>"/>.<?php echo $current_site->domain;?>
-						<?php else:
+						<?php if ( constant( "VHOST" ) == 'yes' ) { ?>
+							<input name="blog[domain]" type="text" title="<?php _e('Domain') ?>"/>.<?php echo $current_site->domain;?> 
+						<?php } else {
 							echo $current_site->domain . $current_site->path ?><input name="blog[domain]" type="text" title="<?php _e('Domain') ?>"/>
-						<?php endif; ?>
+						<?php } 
+						echo "<p>" . __( 'Only the characters a-z and 0-9 recommended.' ) . "</p>";
+						?>
 						</td>
 					</tr>
 					<tr class="form-field form-required">
