@@ -1,7 +1,7 @@
 <?php
 require_once('admin.php');
 if( is_site_admin() == false ) {
-    wp_die( __('You do not have permission to access this page.') );
+	wp_die( __('You do not have permission to access this page.') );
 }
 
 do_action('wpmuadminedit', '');
@@ -17,7 +17,6 @@ if( isset( $_POST['ref'] ) == false && !empty($_SERVER['HTTP_REFERER']) ) {
 }
 
 switch( $_GET['action'] ) {
-	// Options
 	case "siteoptions":
 		check_admin_referer('siteoptions');
 		if( empty( $_POST ) )
@@ -36,9 +35,6 @@ switch( $_GET['action'] ) {
 		}
 		update_site_option( "illegal_names", $names );
 
-		update_site_option( "registration", $_POST['registration'] );
-		update_site_option( "registrationnotification", $_POST['registrationnotification'] );
-
 		if( $_POST['limited_email_domains'] != '' ) {
 			$limited_email_domains = str_replace( ' ', "\n", $_POST[ 'limited_email_domains' ] );
 			$limited_email_domains = split( "\n", stripslashes( $limited_email_domains ) );
@@ -59,16 +55,56 @@ switch( $_GET['action'] ) {
 		} else {
 			update_site_option( "banned_email_domains", '' );
 		}
-
-		update_site_option( "menu_items", $_POST['menu_items'] );
-		update_site_option( "mu_media_buttons", $_POST['mu_media_buttons'] );
-		update_site_option( "blog_upload_space", $_POST['blog_upload_space'] );
-		update_site_option( "upload_filetypes", $_POST['upload_filetypes'] );
-		update_site_option( "site_name", $_POST['site_name'] );
-		update_site_option( "first_post", $_POST['first_post'] );
-		update_site_option( "welcome_email", $_POST['welcome_email'] );
-		update_site_option( "fileupload_maxk", $_POST['fileupload_maxk'] );
-		update_site_option( "admin_notice_feed", clean_url( $_POST['admin_notice_feed'] ) );
+		update_site_option( 'default_user_role', $_POST[ 'default_user_role' ] );
+		if( trim( $_POST[ 'dashboard_blog_orig' ] ) == '' )
+			$_POST[ 'dashboard_blog_orig' ] = $current_site->blog_id;
+		if( trim( $_POST[ 'dashboard_blog' ] ) == '' ) {
+			$_POST[ 'dashboard_blog' ] = $current_site->blog_id;
+			$dashboard_blog_id = $current_site->blog_id;
+		} else {
+			$dashboard_blog = untrailingslashit( sanitize_user( str_replace( '.', '', str_replace( $current_site->domain . $current_site->path, '', $_POST[ 'dashboard_blog' ] ) ) ) );
+			$blog_details = get_blog_details( $dashboard_blog );
+			if ( false === $blog_details ) {
+				if ( is_numeric( $dashboard_blog ) )
+					wp_die( __( 'Dashboard blog_id must be a blog that already exists' ) );
+				if ( constant( 'VHOST' ) == 'yes' ) {
+					$domain = $dashboard_blog . '.' . $current_site->domain;
+					$path = $current_site->path;
+				} else {
+					$domain = $current_site->domain;
+					$path = trailingslashit( $current_site->path . $dashboard_blog );
+				}
+				$wpdb->hide_errors();
+				$dashboard_blog_id = wpmu_create_blog( $domain, $path, __( 'My Dashboard' ), $current_user->id , array( "public" => 0 ), $current_site->id );
+				$wpdb->show_errors();
+			} else {
+				$dashboard_blog_id = $blog_details->blog_id;
+			}
+		}
+		if ( is_wp_error( $dashboard_blog_id ) ) {
+			wp_die( __( 'Problem creating dashboard blog: ' ) . $dashboard_blog_id->get_error_message() );
+		}
+		if( $_POST[ 'dashboard_blog_orig' ] != $_POST[ 'dashboard_blog' ] ) {
+			$users = get_users_of_blog( get_site_option( 'dashboard_blog' ) );
+			$move_users = array();
+			foreach ( (array)$users as $user ) {
+				if( array_pop( array_keys( unserialize( $user->meta_value ) ) ) == 'subscriber' )
+					$move_users[] = $user->user_id;
+			}
+			if ( false == empty( $move_users ) ) {
+				foreach ( (array)$move_users as $user_id ) {
+					remove_user_from_blog($user_id, get_site_option( 'dashboard_blog' ) );
+					add_user_to_blog( $dashboard_blog_id, $user_id, get_site_option( 'default_user_role', 'subscriber' ) );
+					update_usermeta( $user_id, 'primary_blog', $dashboard_blog_id );
+				}
+			}
+		}
+		update_site_option( "dashboard_blog", $dashboard_blog_id );
+		$options = array( 'registrationnotification', 'registration', 'add_new_users', 'menu_items', 'mu_media_buttons', 'upload_space_check_disabled', 'blog_upload_space', 'upload_filetypes', 'site_name', 'first_post', 'first_page', 'first_comment', 'first_comment_url', 'first_comment_author', 'welcome_email', 'welcome_user_email', 'fileupload_maxk', 'admin_notice_feed' );
+		foreach( $options as $option_name ) {
+			$value = stripslashes_deep( $_POST[ $option_name ] );
+			update_site_option( $option_name, $value );
+		}
 
 		$site_admins = explode( ' ', str_replace( ",", " ", $_POST['site_admins'] ) );
 		if ( is_array( $site_admins ) ) {
@@ -78,7 +114,7 @@ switch( $_GET['action'] ) {
 				foreach( (array) $site_admins as $site_admin ) {
 					$uid = $wpdb->get_var( "SELECT ID FROM {$wpdb->users} WHERE user_login='{$site_admin}'" );
 					if( $uid )
-						add_user_to_blog( $mainblog_id, $uid, 'Administrator' );
+						add_user_to_blog( $mainblog_id, $uid, 'administrator' );
 				}
 			}
 			update_site_option( 'site_admins' , $site_admins );
@@ -87,14 +123,15 @@ switch( $_GET['action'] ) {
 		// Update more options here
 		do_action( 'update_wpmu_options' );
 
-		wp_redirect( add_query_arg( "updated", "true", $_SERVER['HTTP_REFERER'] ) );
+		wp_redirect( add_query_arg( "updated", "true", 'wpmu-options.php' ) );
 		exit();
 	break;
-
-	// Blogs
 	case "addblog":
 		check_admin_referer('add-blog');
 
+		if( is_array( $_POST[ 'blog' ] ) == false ) {
+			wp_die( "Can't create an empty blog." );
+		}
 		$blog = $_POST['blog'];
 		$domain = sanitize_user( str_replace( '/', '', $blog[ 'domain' ] ) );
 		$email = sanitize_email( $blog[ 'email' ] );
@@ -105,7 +142,7 @@ switch( $_GET['action'] ) {
 		if( !is_email( $email ) ) 
 			wp_die( __('Invalid email address') ); 
 
-		if( constant('VHOST') == 'yes' ) {
+		if( constant( 'VHOST' ) == 'yes' ) {
 			$newdomain = $domain.".".$current_site->domain;
 			$path = $base;
 		} else {
@@ -113,13 +150,9 @@ switch( $_GET['action'] ) {
 			$path = $base.$domain.'/';
 		}
 
-		$domain = strtolower( $domain );
-		$newdomain = strtolower( $newdomain );
-		$path = strtolower( $path );
-
 		$password = 'N/A';
 		$user_id = email_exists($email);
-		if( !$user_id ) {
+		if( !$user_id ) { // Create a new user with a random password
 			$password = generate_random_password();
 			$user_id = wpmu_create_user( $domain, $password, $email );
 			if(false == $user_id) {
@@ -133,7 +166,8 @@ switch( $_GET['action'] ) {
 		$id = wpmu_create_blog($newdomain, $path, $title, $user_id , array( "public" => 1 ), $current_site->id);
 		$wpdb->show_errors();
 		if( !is_wp_error($id) ) {
-			if( get_user_option( $user_id, 'primary_blog' ) == 1 )
+			$dashboard_blog = get_dashboard_blog();
+			if( get_user_option( 'primary_blog', $user_id ) == $dashboard_blog->blog_id )
 				update_user_option( $user_id, 'primary_blog', $id, true );
 			$content_mail = sprintf( __( "New blog created by %1s\n\nAddress: http://%2s\nName: %3s"), $current_user->user_login , $newdomain.$path, stripslashes( $title ) );
 			wp_mail( get_site_option('admin_email'),  sprintf(__('[%s] New Blog Created'), $current_site->site_name), $content_mail, 'From: "Site Admin" <' . get_site_option( 'admin_email' ) . '>' );
@@ -151,105 +185,118 @@ switch( $_GET['action'] ) {
 			wp_die( __('You probably need to go back to the <a href="wpmu-blogs.php">blogs page</a>') );
 
 		// themes
-		if( is_array( $_POST['theme'] ) ) {
-			$_POST['option']['allowedthemes'] = $_POST['theme'];
+		if( is_array( $_POST[ 'theme' ] ) ) {
+			$_POST[ 'option' ][ 'allowedthemes' ] = $_POST[ 'theme' ];
 		} else {
-			$_POST['option']['allowedthemes'] = '';
+			$_POST[ 'option' ][ 'allowedthemes' ] = '';
 		}
 
-		if( is_array( $_POST['option'] ) ) {
+		switch_to_blog( $id );
+		if( is_array( $_POST[ 'option' ] ) ) {
 			$c = 1;
-			$count = count( $_POST['option'] );
+			$count = count( $_POST[ 'option' ] );
 			foreach ( (array) $_POST['option'] as $key => $val ) {
+				if( $key === 0 )
+					continue; // Avoids "0 is a protected WP option and may not be modified" error when edit blog options
 				if( $c == $count ) {
-					update_blog_option( $id, $key, $val );
+					update_option( $key, $val );
 				} else {
-					update_blog_option( $id, $key, $val, false ); // no need to refresh blog details yet
+					update_option( $key, $val, false ); // no need to refresh blog details yet
 				}
 				$c++;
 			}
 		}
 
-		if( get_blog_option( $id, 'siteurl' ) != 'http://' . $_POST['blog']['domain'] . $_POST['blog']['path'] )
-			update_blog_option( $id, 'siteurl', 'http://' . $_POST['blog']['domain'] . $_POST['blog']['path'] );
+		if( $_POST['update_home_url'] == 'update' ) {
+			if( get_option( 'siteurl' ) != 'http://' . $_POST['blog']['domain'] . $_POST['blog']['path'] )
+				update_option( 'siteurl', 'http://' . $_POST['blog']['domain'] . $_POST['blog']['path'] );
 
-		if( get_blog_option( $id, 'home' ) != 'http://' . $_POST['blog']['domain'] . $_POST['blog']['path'] )
-			update_blog_option( $id, 'home', 'http://' . $_POST['blog']['domain'] . $_POST['blog']['path'] );
+			if( get_option( 'home' ) != 'http://' . $_POST['blog']['domain'] . $_POST['blog']['path'] )
+				update_option( 'home', 'http://' . $_POST['blog']['domain'] . $_POST['blog']['path'] );
+		}
+			
 		$wp_rewrite->flush_rules();
 
 		// update blogs table
-		$result = $wpdb->query("UPDATE {$wpdb->blogs} SET
-				domain       = '".$_POST['blog']['domain']."',
-				path         = '".$_POST['blog']['path']."',
-				registered   = '".$_POST['blog']['registered']."',
-				public       = '".$_POST['blog']['public']."',
-				archived     = '".$_POST['blog']['archived']."',
-				mature       = '".$_POST['blog']['mature']."',
-				deleted      = '".$_POST['blog']['deleted']."',
-				spam         = '".$_POST['blog']['spam']."' 
-			WHERE  blog_id = '$id'");
+		$result = $wpdb->query( "UPDATE {$wpdb->blogs} SET
+				domain       = '".$_POST[ 'blog' ][ 'domain' ]."',
+				path         = '".$_POST[ 'blog' ][ 'path' ]."',
+				registered   = '".$_POST[ 'blog' ][ 'registered' ]."',
+				public       = '".$_POST[ 'blog' ][ 'public' ]."',
+				archived     = '".$_POST[ 'blog' ][ 'archived' ]."',
+				mature       = '".$_POST[ 'blog' ][ 'mature' ]."',
+				deleted      = '".$_POST[ 'blog' ][ 'deleted' ]."',
+				spam         = '".$_POST[ 'blog' ][ 'spam' ]."'
+			WHERE  blog_id = '$id'" );
 
-		update_blog_status( $id, 'spam', $_POST['blog']['spam'] );
+		update_blog_status( $id, 'spam', $_POST[ 'blog' ][ 'spam' ] );
+		update_option( 'blog_public', $_POST[ 'blog' ][ 'public' ] );
 
+		// get blog prefix
+		$blog_prefix = $wpdb->get_blog_prefix( $id );
 		// user roles
-		if( is_array( $_POST['role'] ) == true ) {
-			$newroles = $_POST['role'];
+		if( is_array( $_POST[ 'role' ] ) == true ) {
+			$newroles = $_POST[ 'role' ];
 			reset( $newroles );
 			foreach ( (array) $newroles as $userid => $role ) {
 				$role_len = strlen( $role );
-				$existing_role = $wpdb->get_var( "SELECT meta_value FROM $wpdb->usermeta WHERE user_id = '$userid'  AND meta_key = '" . $wpdb->base_prefix . $id . "_capabilities'" );
+				$existing_role = $wpdb->get_var( "SELECT meta_value FROM $wpdb->usermeta WHERE user_id = '$userid'  AND meta_key = '" . $blog_prefix. "capabilities'" );
 				if( false == $existing_role ) {
-					$wpdb->query( "INSERT INTO " . $wpdb->usermeta . "( `umeta_id` , `user_id` , `meta_key` , `meta_value` ) VALUES ( NULL, '$userid', '" . $wpdb->base_prefix . $id . "_capabilities', 'a:1:{s:" . strlen( $role ) . ":\"" . $role . "\";b:1;}')" );
+					$wpdb->query( "INSERT INTO " . $wpdb->usermeta . "( `umeta_id` , `user_id` , `meta_key` , `meta_value` ) VALUES ( NULL, '$userid', '" . $blog_prefix . "capabilities', 'a:1:{s:" . strlen( $role ) . ":\"" . $role . "\";b:1;}')" );
 				} elseif( $existing_role != "a:1:{s:" . strlen( $role ) . ":\"" . $role . "\";b:1;}" ) {
-					$wpdb->query( "UPDATE $wpdb->usermeta SET meta_value = 'a:1:{s:" . strlen( $role ) . ":\"" . $role . "\";b:1;}' WHERE user_id = '$userid'  AND meta_key = '" . $wpdb->base_prefix . $id . "_capabilities'" );
+					$wpdb->query( "UPDATE $wpdb->usermeta SET meta_value = 'a:1:{s:" . strlen( $role ) . ":\"" . $role . "\";b:1;}' WHERE user_id = '$userid'  AND meta_key = '" . $blog_prefix . "capabilities'" );
 				}
 
 			}
 		}
 
 		// remove user
-		if( is_array( $_POST['blogusers'] ) ) {
-			reset( $_POST['blogusers'] );
-			foreach ( (array) $_POST['blogusers'] as $key => $val )
+		if( is_array( $_POST[ 'blogusers' ] ) ) {
+			reset( $_POST[ 'blogusers' ] );
+			foreach ( (array) $_POST[ 'blogusers' ] as $key => $val )
 				remove_user_from_blog( $key, $id );
 		}
 
 		// change password
-		if( is_array( $_POST['user_password'] ) ) {
-			reset( $_POST['user_password'] );
-			$newroles = $_POST['role'];
-			foreach ( (array) $_POST['user_password'] as $userid => $pass ) {
-				unset( $_POST['role'] );
-				$_POST['role'] = $newroles[ $userid ];
+		if( is_array( $_POST[ 'user_password' ] ) ) {
+			reset( $_POST[ 'user_password' ] );
+			$newroles = $_POST[ 'role' ];
+			foreach ( (array) $_POST[ 'user_password' ] as $userid => $pass ) {
+				unset( $_POST[ 'role' ] );
+				$_POST[ 'role' ] = $newroles[ $userid ];
 				if( $pass != '' ) {
-					$cap = $wpdb->get_var( "SELECT meta_value FROM {$wpdb->usermeta} WHERE user_id = '{$userid}' AND meta_key = '{$wpdb->base_prefix}{$wpdb->blogid}_capabilities' AND meta_value = 'a:0:{}'" );
+					$cap = $wpdb->get_var( "SELECT meta_value FROM {$wpdb->usermeta} WHERE user_id = '{$userid}' AND meta_key = '{$blog_prefix}capabilities' AND meta_value = 'a:0:{}'" );
 					$userdata = get_userdata($userid);
-					$_POST['pass1'] = $_POST['pass2'] = $pass;
-					$_POST['email'] = $userdata->user_email;
-					$_POST['rich_editing'] = $userdata->rich_editing;
+					$_POST[ 'pass1' ] = $_POST[ 'pass2' ] = $pass;
+					$_POST[ 'email' ] = $userdata->user_email;
+					$_POST[ 'rich_editing' ] = $userdata->rich_editing;
 					edit_user( $userid );
 					if( $cap == null )
-						$wpdb->query( "DELETE FROM {$wpdb->usermeta} WHERE user_id = '{$userid}' AND meta_key = '{$wpdb->base_prefix}{$wpdb->blogid}_capabilities' AND meta_value = 'a:0:{}'" );
+						$wpdb->query( "DELETE FROM {$wpdb->usermeta} WHERE user_id = '{$userid}' AND meta_key = '{$blog_prefix}capabilities' AND meta_value = 'a:0:{}'" );
 				}
 			}
-			unset( $_POST['role'] );
-			$_POST['role'] = $newroles;
+			unset( $_POST[ 'role' ] );
+			$_POST[ 'role' ] = $newroles;
 		}
 
 		// add user?
-		if( $_POST['newuser'] != '' ) {
-			$newuser = $_POST['newuser'];
+		if( $_POST[ 'newuser' ] != '' ) {
+			$newuser = $_POST[ 'newuser' ];
 			$userid = $wpdb->get_var( $wpdb->prepare( "SELECT ID FROM " . $wpdb->users . " WHERE user_login = %s", $newuser ) );
-			if( $userid )
-				add_user_to_blog( $id, $userid, $_POST['new_role'] );
+			if( $userid ) {
+				$user = $wpdb->get_var( "SELECT user_id FROM " . $wpdb->usermeta . " WHERE user_id='$userid' AND meta_key='wp_" . $id . "_capabilities'" );
+				if( $user == false )
+					add_user_to_blog($id, $userid, $_POST[ 'new_role' ]);
+			}
 		}
 		do_action( 'wpmu_update_blog_options' );
+		restore_current_blog();
 		wpmu_admin_do_redirect( "wpmu-blogs.php?action=editblog&updated=true&id=".$id );
 	break;
 
 	case "deleteblog":
 		check_admin_referer('deleteblog');
-		if( $id != '0' && $id != '1' )
+		if( $id != '0' && $id != $current_site->blog_id )
 			wpmu_delete_blog( $id, true );
 
 		wp_redirect( add_query_arg( array('updated' => 'true', 'action' => 'delete'), $_POST[ 'ref' ] ) );
@@ -258,8 +305,8 @@ switch( $_GET['action'] ) {
 
 	case "allblogs":
 		check_admin_referer('allblogs');
-		foreach ( (array) $_POST['allblogs'] as $key => $val ) {
-			if( $val != '0' && $val != '1' ) {
+		foreach ( (array) $_POST[ 'allblogs' ] as $key => $val ) {
+			if( $val != '0' && $val != $current_site->blog_id ) {
 				if ( isset($_POST['allblog_delete']) ) {
 					$blogfunction = 'all_delete';
 					wpmu_delete_blog( $val, true );
@@ -314,7 +361,6 @@ switch( $_GET['action'] ) {
 	case "unspamblog":
 		check_admin_referer('unspamblog');
 		update_blog_status( $id, "spam", '0' );
-		do_action( "unspam_blog", $id );
 		wp_redirect( add_query_arg( array('updated' => 'true', 'action' => 'unspam'), $_POST['ref'] ) );
 		exit();
 	break;
@@ -322,7 +368,6 @@ switch( $_GET['action'] ) {
 	case "spamblog":
 		check_admin_referer('spamblog');
 		update_blog_status( $id, "spam", '1' );
-		do_action( 'make_spam_blog', $id );
 		wp_redirect( add_query_arg( array('updated' => 'true', 'action' => 'spam'), $_POST['ref'] ) );
 		exit();
 	break;
@@ -365,6 +410,16 @@ switch( $_GET['action'] ) {
 			nocache_headers();
 			header( 'Content-Type: text/html; charset=utf-8' );
 		}
+		$blog_details = get_blog_details( $_GET[ 'id' ] );
+		$confirmation_messages = array( "activateblog" => __( "You are about to activate the blog %s" ),
+						"deactivateblog" => __( "You are about to deactivate the blog %s" ),
+						"unarchiveblog" => __( "You are about to unarchive the blog %s" ),
+						"archiveblog" => __( "You are about to archive the blog %s" ),
+						"unspamblog" => __( "You are about to unspam the blog %s" ),
+						"spamblog" => __( "You are about to mark the blog %s as spam" ),
+						"deleteblog" => __( "You are about to delete the blog %s" ),
+				);
+
 		?>
 		<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 		<html xmlns="http://www.w3.org/1999/xhtml" <?php if ( function_exists('language_attributes') ) language_attributes(); ?>>
@@ -377,11 +432,11 @@ switch( $_GET['action'] ) {
 			<body id="error-page">
 				<h1 id="logo"><img alt="WordPress" src="images/wordpress-logo.png" /></h1>
 				<form action='wpmu-edit.php?action=<?php echo wp_specialchars( $_GET[ 'action2' ] ) ?>' method='post'>
-					<input type='hidden' name='action' value='<?php echo wp_specialchars( $_GET['action2'] ) ?>' />
-					<input type='hidden' name='id' value='<?php echo wp_specialchars( $id ); ?>' />
+					<input type='hidden' name='action' value='<?php echo esc_attr( $_GET['action2'] ) ?>' />
+					<input type='hidden' name='id' value='<?php echo intval( $id ); ?>' />
 					<input type='hidden' name='ref' value='<?php echo $referrer; ?>' />
 					<?php wp_nonce_field( $_GET['action2'] ) ?>
-					<p><?php echo wp_specialchars( stripslashes($_GET['msg']) ); ?></p>
+					<p><?php printf( __( $confirmation_messages[ $_GET[ 'action2' ] ] ), $blog_details->siteurl ); ?></p>
 					<p class="submit"><input class="button" type='submit' value='<?php _e("Confirm"); ?>' /></p>						
 				</form>
 			</body>
@@ -389,7 +444,7 @@ switch( $_GET['action'] ) {
 		<?php
 	break;
 
-	// Users
+	// Users (not used any more)
 	case "deleteuser":
 		check_admin_referer('deleteuser');
 		if( $id != '0' && $id != '1' )
@@ -410,7 +465,7 @@ switch( $_GET['action'] ) {
 			if( is_array( $_POST[ 'blog' ] ) && !empty( $_POST[ 'blog' ] ) ) {
 				foreach( $_POST[ 'blog' ] as $id => $users ) {
 					foreach( $users as $blogid => $user_id ) {
-						$wpdb->query( "UPDATE {$wpdb->base_prefix}{$blogid}_posts SET post_author = '{$user_id}' WHERE post_author = '{$id}'" );
+						remove_user_from_blog( $id, $blogid, $user_id );
 					}
 				}
 			}
@@ -420,16 +475,20 @@ switch( $_GET['action'] ) {
 
 			wp_redirect( add_query_arg( array('updated' => 'true', 'action' => 'all_delete'), 'wpmu-users.php' ) );
 		} else {
-		foreach ( (array) $_POST['allusers'] as $key => $val ) {
-			if( $val != '' && $val != '0' && $val != '1' ) {
-				$user_details = get_userdata( $val );
+			foreach ( (array) $_POST['allusers'] as $key => $val ) {
+				if( $val == '' || $val == '0' ) {
+					continue;
+				}
+				$user = new WP_User( $val );
+				if ( in_array( $user->user_login, get_site_option( 'site_admins', array( 'admin' ) ) ) ) {
+					wp_die( sprintf( __( 'Warning! User cannot be modified. The user %s is a site admnistrator.' ), $user->user_login ) );
+				}
 				if ( isset($_POST['alluser_spam']) ) {
 					$userfunction = 'all_spam';
 					$blogs = get_blogs_of_user( $val, true );
 					foreach ( (array) $blogs as $key => $details ) {
-						if ( $details->userblog_id == 1 ) { continue; } // main blog not a spam !
+						if ( $details->userblog_id == $current_site->blog_id ) { continue; } // main blog not a spam !
 						update_blog_status( $details->userblog_id, "spam", '1' );
-						do_action( "make_spam_blog", $details->userblog_id );
 					}
 					update_user_status( $val, "spam", '1', 1 );
 				} elseif ( isset($_POST['alluser_notspam']) ) {
@@ -441,8 +500,7 @@ switch( $_GET['action'] ) {
 					update_user_status( $val, "spam", '0', 1 );
 				}
 			}
-		}
-		wp_redirect( add_query_arg( array('updated' => 'true', 'action' => $userfunction), $_SERVER['HTTP_REFERER'] ) );
+			wp_redirect( add_query_arg( array('updated' => 'true', 'action' => $userfunction), $_SERVER['HTTP_REFERER'] ) );
 		}
 		exit();
 	break;
@@ -450,6 +508,9 @@ switch( $_GET['action'] ) {
 	case "adduser":
 		check_admin_referer('add-user');
 
+		if( is_array( $_POST[ 'user' ] ) == false ) {
+			wp_die( __( "Cannot create an empty user." ) );
+		}
 		$user = $_POST['user'];
 		if ( empty($user['username']) && empty($user['email']) ) {
 			wp_die( __('Missing username and email.') );
@@ -467,7 +528,11 @@ switch( $_GET['action'] ) {
 		} else {
 			wp_new_user_notification($user_id, $password);
 		}
-		add_user_to_blog('1', $user_id, 'subscriber');
+		if ( get_site_option( 'dashboard_blog' ) == false ) {
+			add_user_to_blog( $current_site->blog_id, $user_id, get_site_option( 'default_user_role', 'subscriber' ) );
+		} else {
+			add_user_to_blog( get_site_option( 'dashboard_blog' ), $user_id, get_site_option( 'default_user_role', 'subscriber' ) );
+		}
 
 		wp_redirect( add_query_arg( array('updated' => 'true', 'action' => 'add'), $_SERVER['HTTP_REFERER'] ) );
 		exit();
@@ -477,5 +542,4 @@ switch( $_GET['action'] ) {
 		wpmu_admin_do_redirect( "wpmu-admin.php" );
 	break;
 }
-
 ?>
