@@ -1,6 +1,6 @@
 <?php
 define( 'SHORTINIT', true ); // this prevents most of WP from being loaded
-require_once( dirname( dirname( __FILE__) ) . '/wp-config.php' ); // absolute includes are faster
+require_once( dirname( dirname( __FILE__) ) . '/wp-load.php' ); // absolute includes are faster
 
 if ( $current_blog->archived == '1' || $current_blog->spam == '1' || $current_blog->deleted == '1' ) {
 	status_header( 404 );
@@ -65,17 +65,16 @@ function wp_check_filetype($filename, $mimes = null) {
 endif;
 
 
-$file = constant( 'ABSPATH' ) . constant( 'UPLOADS' ) . str_replace( '..', '', $_GET[ 'file' ] );
+$file = BLOGUPLOADDIR . str_replace( '..', '', $_GET[ 'file' ] );
 if ( !is_file( $file ) ) {
 	status_header( 404 );
 	die('404 &#8212; File not found.');
 }
 
-if( function_exists( 'mime_content_type' ) ) {
-	$mime[ 'type' ] = mime_content_type( $file );
-} else {
-	$mime = wp_check_filetype( $_SERVER[ 'REQUEST_URI' ] );
-}
+$mime = wp_check_filetype( $_SERVER[ 'REQUEST_URI' ] );
+if( $mime[ 'type' ] === false && function_exists( 'mime_content_type' ) )
+		$mime[ 'type' ] = mime_content_type( $file );
+
 if( $mime[ 'type' ] != false ) {
 	$mimetype = $mime[ 'type' ];
 } else {
@@ -83,7 +82,17 @@ if( $mime[ 'type' ] != false ) {
 	$mimetype = "image/$ext";
 }
 @header( 'Content-type: ' . $mimetype ); // always send this
-@header( 'Content-Length: ' . filesize( $file ) );
+if ( false === strpos( $_SERVER['SERVER_SOFTWARE'], 'Microsoft-IIS' ) )
+	@header( 'Content-Length: ' . filesize( $file ) );
+
+// Optional support for X-Sendfile and X-Accel-Redirect
+if ( defined('WPMU_ACCEL_REDIRECT') && WPMU_ACCEL_REDIRECT ) {
+	@header( 'X-Accel-Redirect: ' . str_replace( WP_CONTENT_DIR, '', $file ) );
+	exit;
+} elseif ( defined('WPMU_SENDFILE') && WPMU_SENDFILE ) {
+	@header( 'X-Sendfile: ' . $file );
+	exit;
+}
 
 $last_modified = gmdate('D, d M Y H:i:s', filemtime( $file ));
 $etag = '"' . md5($last_modified) . '"';
@@ -97,6 +106,8 @@ if (isset($_SERVER['HTTP_IF_NONE_MATCH']))
 else
 	$client_etag = false;
 
+if( !isset( $_SERVER['HTTP_IF_MODIFIED_SINCE'] ) )
+	$_SERVER['HTTP_IF_MODIFIED_SINCE'] = false;
 $client_last_modified = trim( $_SERVER['HTTP_IF_MODIFIED_SINCE']);
 // If string is empty, return 0. If not, attempt to parse into a timestamp
 $client_modified_timestamp = $client_last_modified ? strtotime($client_last_modified) : 0;
