@@ -10,14 +10,22 @@
  */
 
 if ( !defined('WP_MEMORY_LIMIT') )
-	define('WP_MEMORY_LIMIT', '32M');
+	define('WP_MEMORY_LIMIT', '64M');
 
 if ( function_exists('memory_get_usage') && ( (int) @ini_get('memory_limit') < abs(intval(WP_MEMORY_LIMIT)) ) )
 	@ini_set('memory_limit', WP_MEMORY_LIMIT);
 
+set_magic_quotes_runtime(0);
+@ini_set('magic_quotes_sybase', 0);
+
+if ( function_exists('date_default_timezone_set') )
+	date_default_timezone_set('UTC');
+
+if ( defined( 'VHOST' ) && ( constant( 'VHOST' ) != 'yes' && constant( 'VHOST' ) != 'no' ) )
+	die( "Warning! VHOST must be 'yes' or 'no' in wp-config.php" );
 
 /**
- * wp_unregister_GLOBALS() - Turn register globals off
+ * Turn register globals off.
  *
  * @access private
  * @since 2.1.0
@@ -55,8 +63,8 @@ unset( $wp_filter, $cache_lastcommentmodified, $cache_lastpostdate );
 if ( ! isset($blog_id) )
 	$blog_id = 0;
 
-// Fix for IIS, which doesn't set REQUEST_URI
-if ( empty( $_SERVER['REQUEST_URI'] ) ) {
+// Fix for IIS when running with PHP ISAPI
+if ( empty( $_SERVER['REQUEST_URI'] ) || ( php_sapi_name() != 'cgi-fcgi' && preg_match( '/^Microsoft-IIS\//', $_SERVER['SERVER_SOFTWARE'] ) ) ) {
 
 	// IIS Mod-Rewrite
 	if (isset($_SERVER['HTTP_X_ORIGINAL_URL'])) {
@@ -103,16 +111,48 @@ if ( version_compare( '4.3', phpversion(), '>' ) ) {
 if ( !defined('WP_CONTENT_DIR') )
 	define( 'WP_CONTENT_DIR', ABSPATH . 'wp-content' ); // no trailing slash, full paths only - WP_CONTENT_URL is defined further down
 
+if ( file_exists(ABSPATH . '.maintenance') && !defined('WP_INSTALLING') ) {
+	include(ABSPATH . '.maintenance');
+	// If the $upgrading timestamp is older than 10 minutes, don't die.
+	if ( ( time() - $upgrading ) < 600 ) {
+		if ( file_exists( WP_CONTENT_DIR . '/maintenance.php' ) ) {
+			require_once( WP_CONTENT_DIR . '/maintenance.php' );
+			die();
+		}
+
+		$protocol = $_SERVER["SERVER_PROTOCOL"];
+		if ( 'HTTP/1.1' != $protocol && 'HTTP/1.0' != $protocol )
+			$protocol = 'HTTP/1.0';
+		header( "$protocol 503 Service Unavailable", true, 503 );
+		header( 'Content-Type: text/html; charset=utf-8' );
+		header( 'Retry-After: 600' );
+?>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
+<html xmlns="http://www.w3.org/1999/xhtml">
+<head>
+<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
+	<title>Maintenance</title>
+
+</head>
+<body>
+	<h1>Briefly unavailable for scheduled maintenance. Check back in a minute.</h1>
+</body>
+</html>
+<?php
+		die();
+	}
+}
+
 if ( !extension_loaded('mysql') && !file_exists(WP_CONTENT_DIR . '/db.php') )
 	die( /*WP_I18N_OLD_MYSQL*/'Your PHP installation appears to be missing the MySQL extension which is required by WordPress.'/*/WP_I18N_OLD_MYSQL*/ );
 
 /**
- * timer_start() - PHP 4 standard microtime start capture
+ * PHP 4 standard microtime start capture.
  *
  * @access private
  * @since 0.71
- * @global int $timestart Seconds and Microseconds added together from when function is called
- * @return bool Always returns true
+ * @global int $timestart Seconds and Microseconds added together from when function is called.
+ * @return bool Always returns true.
  */
 function timer_start() {
 	global $timestart;
@@ -123,7 +163,7 @@ function timer_start() {
 }
 
 /**
- * timer_stop() - Return and/or display the time from the page start to when function is called.
+ * Return and/or display the time from the page start to when function is called.
  *
  * You can get the results and print them by doing:
  * <code>
@@ -160,17 +200,38 @@ function timer_stop($display = 0, $precision = 3) { //if called like timer_stop(
 }
 timer_start();
 
-// Add define('WP_DEBUG',true); to wp-config.php to enable display of notices during development.
-if (defined('WP_DEBUG') and WP_DEBUG == true) {
-	error_reporting(E_ALL);
+// Add define('WP_DEBUG', true); to wp-config.php to enable display of notices during development.
+if ( defined('WP_DEBUG') && WP_DEBUG ) {
+	if ( defined('E_DEPRECATED') )
+		error_reporting(E_ALL & ~E_DEPRECATED & ~E_STRICT);
+	else
+		error_reporting(E_ALL);
+	// Add define('WP_DEBUG_DISPLAY', false); to wp-config.php to use the globally configured setting for display_errors and not force it to On
+	if ( ! defined('WP_DEBUG_DISPLAY') || WP_DEBUG_DISPLAY )
+		ini_set('display_errors', 1);
+	// Add define('WP_DEBUG_LOG', true); to enable php debug logging to WP_CONTENT_DIR/debug.log
+	if ( defined('WP_DEBUG_LOG') && WP_DEBUG_LOG ) {
+		ini_set('log_errors', 1);
+		ini_set('error_log', WP_CONTENT_DIR . '/debug.log');
+	}
 } else {
-	error_reporting(E_ALL ^ E_NOTICE ^ E_USER_NOTICE);
+	define('WP_DEBUG', false);
+	if ( defined('E_RECOVERABLE_ERROR') )
+		error_reporting(E_ERROR | E_WARNING | E_PARSE | E_USER_ERROR | E_USER_WARNING | E_RECOVERABLE_ERROR);
+	else
+		error_reporting(E_ERROR | E_WARNING | E_PARSE | E_USER_ERROR | E_USER_WARNING);
 }
 
 // For an advanced caching plugin to use, static because you would only want one
-if ( defined('WP_CACHE') )
+if ( defined('WP_CACHE') && WP_CACHE )
 	@include WP_CONTENT_DIR . '/advanced-cache.php';
 
+/**
+ * Private
+ */ 
+if ( !defined('MEDIA_TRASH') )
+	define('MEDIA_TRASH', false);
+
 /**
  * Stores the location of the WordPress directory of functions, classes, and core content.
  *
@@ -209,24 +270,85 @@ require_wp_db();
 if ( !empty($wpdb->error) )
 	dead_db();
 
+/**
+ * Format specifiers for DB columns. Columns not listed here default to %s.
+ * @since 2.8.0
+ * @see wpdb:$field_types
+ * @see wpdb:prepare()
+ * @see wpdb:insert()
+ * @see wpdb:update()
+ */
+$wpdb->field_types = array( 'post_author' => '%d', 'post_parent' => '%d', 'menu_order' => '%d', 'term_id' => '%d', 'term_group' => '%d', 'term_taxonomy_id' => '%d',
+	'parent' => '%d', 'count' => '%d','object_id' => '%d', 'term_order' => '%d', 'ID' => '%d', 'commment_ID' => '%d', 'comment_post_ID' => '%d', 'comment_parent' => '%d',
+	'user_id' => '%d', 'link_id' => '%d', 'link_owner' => '%d', 'link_rating' => '%d', 'option_id' => '%d', 'blog_id' => '%d', 'meta_id' => '%d', 'post_id' => '%d',
+	'user_status' => '%d', 'umeta_id' => '%d', 'comment_karma' => '%d', 'comment_count' => '%d');
+
 $prefix = $wpdb->set_prefix($table_prefix); // set up global tables
 
 if ( is_wp_error($prefix) )
 	wp_die(/*WP_I18N_BAD_PREFIX*/'<strong>ERROR</strong>: <code>$table_prefix</code> in <code>wp-config.php</code> can only contain numbers, letters, and underscores.'/*/WP_I18N_BAD_PREFIX*/);
 
-if ( file_exists(WP_CONTENT_DIR . '/object-cache.php') )
+/**
+ * Copy an object.
+ *
+ * Returns a cloned copy of an object.
+ *
+ * @since 2.7.0
+ *
+ * @param object $object The object to clone
+ * @return object The cloned object
+ */
+function wp_clone( $object ) {
+	static $can_clone;
+	if ( !isset( $can_clone ) ) {
+		$can_clone = version_compare( phpversion(), '5.0', '>=' );
+	}
+	return $can_clone ? clone( $object ) : $object;
+}
+
+/**
+ * Whether the current request is in WordPress admin Panel
+ *
+ * Does not inform on whether the user is an admin! Use capability checks to
+ * tell if the user should be accessing a section or not.
+ *
+ * @since 1.5.1
+ *
+ * @return bool True if inside WordPress administration pages.
+ */
+function is_admin() {
+	if ( defined('WP_ADMIN') )
+		return WP_ADMIN;
+	return false;
+}
+
+/**
+ * Whether Multisite support is enabled (stub from WP 3.0)
+ * 
+ * @since 2.9.1
+ *
+ * @return bool True always.
+ */
+function is_multisite() {
+	return true;
+}
+
+if ( file_exists(WP_CONTENT_DIR . '/object-cache.php') ) {
 	require_once (WP_CONTENT_DIR . '/object-cache.php');
-else
+	$_wp_using_ext_object_cache = true;
+} else {
 	require_once (ABSPATH . WPINC . '/cache.php');
+	$_wp_using_ext_object_cache = false;
+}
 
 wp_cache_init();
 if ( function_exists('wp_cache_add_global_groups') ) {
-	wp_cache_add_global_groups(array ('users', 'userlogins', 'usermeta', 'site-options', 'site-lookup', 'blog-lookup', 'blog-details', 'rss'));
+	wp_cache_add_global_groups(array ('users', 'userlogins', 'usermeta', 'site-transient', 'site-options', 'site-lookup', 'blog-lookup', 'blog-details', 'rss'));
 	wp_cache_add_non_persistent_groups(array( 'comment', 'counts', 'plugins' ));
 }
 
 if( defined( 'SUNRISE' ) )
-	include_once( ABSPATH . 'wp-content/sunrise.php' );
+	include_once( WP_CONTENT_DIR . '/sunrise.php' );
 
 require_once ( ABSPATH . 'wpmu-settings.php' );
 $wpdb->blogid           = $current_blog->blog_id;
@@ -236,7 +358,7 @@ $table_prefix = $table_prefix . $blog_id . '_';
 
 // Fix empty PHP_SELF
 $PHP_SELF = $_SERVER['PHP_SELF'];
-if ( empty($PHP_SELF) || ( constant( 'VHOST' ) == 'no' && $current_blog->path != '/' ) )
+if ( empty($PHP_SELF) || ( empty($PHP_SELF) && constant( 'VHOST' ) == 'no' && $current_blog->path != '/' ) ) 
 	$_SERVER['PHP_SELF'] = $PHP_SELF = preg_replace("/(\?.*)?$/",'',$_SERVER["REQUEST_URI"]);
 
 wp_cache_init(); // need to init cache again after blog_id is set
@@ -245,17 +367,34 @@ if ( function_exists('wp_cache_add_global_groups') ) { // need to add these agai
 	wp_cache_add_non_persistent_groups(array( 'comment', 'counts', 'plugins' ));
 }
 
+if( !defined( "UPLOADBLOGSDIR" ) )
+	define( "UPLOADBLOGSDIR", 'wp-content/blogs.dir' );
+
 if( !defined( "UPLOADS" ) )
-	define( "UPLOADS", "wp-content/blogs.dir/{$wpdb->blogid}/files/" );
+	define( "UPLOADS", UPLOADBLOGSDIR . "/{$wpdb->blogid}/files/" );
+
+if( !defined( "BLOGUPLOADDIR" ) )
+	define( "BLOGUPLOADDIR", WP_CONTENT_DIR . "/blogs.dir/{$wpdb->blogid}/files/" );
 
 require (ABSPATH . WPINC . '/plugin.php');
 require (ABSPATH . WPINC . '/default-filters.php');
+include_once(ABSPATH . WPINC . '/pomo/mo.php');
+
+/**
+ * Runs just before PHP shuts down execution.
+ *
+ * @access private
+ * @since 1.2.0
+ */
+function shutdown_action_hook() {
+	do_action('shutdown');
+	wp_cache_close();
+}
+register_shutdown_function('shutdown_action_hook');
 
 if( defined( "SHORTINIT" ) && constant( "SHORTINIT" ) == true ) // stop most of WP being loaded, we just want the basics
 	return false;
 
-include_once(ABSPATH . WPINC . '/streams.php');
-include_once(ABSPATH . WPINC . '/gettext.php');
 require_once (ABSPATH . WPINC . '/l10n.php');
 
 if ( !is_blog_installed() && !defined('WP_INSTALLING') ) {
@@ -267,6 +406,7 @@ require (ABSPATH . WPINC . '/capabilities.php');
 require (ABSPATH . WPINC . '/query.php');
 require (ABSPATH . WPINC . '/theme.php');
 require (ABSPATH . WPINC . '/user.php');
+require (ABSPATH . WPINC . '/meta.php');
 require (ABSPATH . WPINC . '/general-template.php');
 require (ABSPATH . WPINC . '/link-template.php');
 require (ABSPATH . WPINC . '/author-template.php');
@@ -290,22 +430,36 @@ require (ABSPATH . WPINC . '/update.php');
 require (ABSPATH . WPINC . '/canonical.php');
 require (ABSPATH . WPINC . '/shortcodes.php');
 require (ABSPATH . WPINC . '/media.php');
+require (ABSPATH . WPINC . '/http.php');
+require (ABSPATH . WPINC . '/widgets.php');
 
 if ( !defined('WP_CONTENT_URL') )
 	define( 'WP_CONTENT_URL', get_option('siteurl') . '/wp-content'); // full url - WP_CONTENT_DIR is defined further up
 
 require_once( ABSPATH . WPINC . '/wpmu-functions.php' );
-require( ABSPATH . WPINC . '/wpmu-default-filters.php' ); // WPmu Filters 
+require_once( ABSPATH . WPINC . '/wpmu-default-filters.php' ); // WPmu Filters 
 
 /**
  * Allows for the plugins directory to be moved from the default location.
  *
- * @since 2.6
+ * @since 2.6.0
  */
 if ( !defined('WP_PLUGIN_DIR') )
 	define( 'WP_PLUGIN_DIR', WP_CONTENT_DIR . '/plugins' ); // full path, no trailing slash
+
+/**
+ * Allows for the plugins directory to be moved from the default location.
+ *
+ * @since 2.6.0
+ */
 if ( !defined('WP_PLUGIN_URL') )
 	define( 'WP_PLUGIN_URL', WP_CONTENT_URL . '/plugins' ); // full url, no trailing slash
+
+/**
+ * Allows for the plugins directory to be moved from the default location.
+ *
+ * @since 2.1.0
+ */
 if ( !defined('PLUGINDIR') )
 	define( 'PLUGINDIR', 'wp-content/plugins' ); // Relative to ABSPATH.  For back compat.
 
@@ -313,50 +467,120 @@ if( !isset($current_site->site_name) )
 	$current_site->site_name = get_site_option('site_name');
 if( $current_site->site_name == false )
 	$current_site->site_name = ucfirst( $current_site->domain );
+	
+if ( ! defined('WP_INSTALLING') ) {
+	// Used to guarantee unique hash cookies
+	if ( !isset($cookiehash) )
+		$cookiehash = '';
 
-// Used to guarantee unique hash cookies
-$cookiehash = '';
-/**
- * Used to guarantee unique hash cookies
- * @since 1.5
- */
-define('COOKIEHASH', '' );
+	/**
+	 * Used to guarantee unique hash cookies
+	 * @since 1.5
+	 */
+	if ( !defined('COOKIEHASH') )
+		define( 'COOKIEHASH', $cookiehash );
+}
 
 $wpdb->hide_errors();
-if( defined( 'MUPLUGINDIR' ) == false ) 
-	define( 'MUPLUGINDIR', 'wp-content/mu-plugins' );
+/**
+ * Allows for the mu-plugins directory to be moved from the default location.
+ *
+ * @since 2.8.0
+ */
+if ( !defined('WPMU_PLUGIN_DIR') )
+	define( 'WPMU_PLUGIN_DIR', WP_CONTENT_DIR . '/mu-plugins' ); // full path, no trailing slash
 
-if( is_dir( ABSPATH . MUPLUGINDIR ) ) {
-	if( $dh = opendir( ABSPATH . MUPLUGINDIR ) ) {
-		while( ( $plugin = readdir( $dh ) ) !== false ) {
-			if( substr( $plugin, -4 ) == '.php' ) {
-				include_once( ABSPATH . MUPLUGINDIR . '/' . $plugin );
-			}
-		}
+/**
+ * Allows for the mu-plugins directory to be moved from the default location.
+ *
+ * @since 2.8.0
+ */
+if ( !defined('WPMU_PLUGIN_URL') )
+	define( 'WPMU_PLUGIN_URL', WP_CONTENT_URL . '/mu-plugins' ); // full url, no trailing slash
+
+/**
+ * Allows for the mu-plugins directory to be moved from the default location.
+ *
+ * @since 2.8.0
+ */
+if ( !defined( 'MUPLUGINDIR' ) )
+	define( 'MUPLUGINDIR', 'wp-content/mu-plugins' ); // Relative to ABSPATH.  For back compat.
+
+if ( is_dir( WPMU_PLUGIN_DIR ) ) {
+	if ( $dh = opendir( WPMU_PLUGIN_DIR ) ) {
+		$mu_plugins = array ();
+		while ( ( $plugin = readdir( $dh ) ) !== false )
+			if ( substr( $plugin, -4 ) == '.php' )
+				$mu_plugins[] = $plugin;
+		closedir( $dh );
+		sort( $mu_plugins );
+		foreach( $mu_plugins as $mu_plugin )
+			include_once( WPMU_PLUGIN_DIR . '/' . $mu_plugin );
 	}
 }
+
+$wpmu_sitewide_plugins = (array) maybe_unserialize( get_site_option( 'wpmu_sitewide_plugins' ) );
+foreach( $wpmu_sitewide_plugins as $plugin_file => $activation_time ) {
+	if ( !$plugin_file )
+		continue;
+
+	if ( !file_exists( WP_PLUGIN_DIR . '/' . $plugin_file ) ) {
+		$deleted_sitewide_plugins[] = $plugin_file;
+	} else {
+		include_once( WP_PLUGIN_DIR . '/' . $plugin_file );
+	}
+}
+
+if ( isset( $deleted_sitewide_plugins ) ) {
+	$active_sitewide_plugins = maybe_unserialize( get_site_option( 'active_sitewide_plugins' ) );
+
+	/* Remove any deleted plugins from the wpmu_sitewide_plugins array */
+	foreach( $deleted_sitewide_plugins as $plugin_file ) {
+		unset( $wpmu_sitewide_plugins[$plugin_file] );
+		unset( $active_sitewide_plugins[$plugin_file] );
+	}
+
+	update_site_option( 'wpmu_sitewide_plugins', $wpmu_sitewide_plugins );
+	update_site_option( 'active_sitewide_plugins', $wpmu_sitewide_plugins );
+}
+
+do_action( 'muplugins_loaded' );
 $wpdb->show_errors();
 
 if ( '1' == $current_blog->deleted ) {
-	header('HTTP/1.1 410 Gone');
-	graceful_fail(__('This user has elected to delete their account and the content is no longer available.'));
+	if ( file_exists( WP_CONTENT_DIR . '/blog-deleted.php' ) ) {
+		require_once( WP_CONTENT_DIR . '/blog-deleted.php' );
+		die();
+	} else {
+		header('HTTP/1.1 410 Gone');
+		graceful_fail(__('This user has elected to delete their account and the content is no longer available.'));
+	}
 }
 
-if ( '2' == $current_blog->deleted )
-	graceful_fail( sprintf( __( 'This blog has not been activated yet. If you are having problems activating your blog, please contact <a href="mailto:%1$s">%1$s</a>.' ), str_replace( '@', ' AT ', get_site_option( 'admin_email', "support@{$current_site->domain}" ) ) ) );
+if ( '2' == $current_blog->deleted ) {
+	if ( file_exists( WP_CONTENT_DIR . '/blog-inactive.php' ) ) {
+		require_once( WP_CONTENT_DIR . '/blog-inactive.php' );
+		die();
+	} else {
+		graceful_fail( sprintf( __( 'This blog has not been activated yet. If you are having problems activating your blog, please contact <a href="mailto:%1$s">%1$s</a>.' ), str_replace( '@', ' AT ', get_site_option( 'admin_email', "support@{$current_site->domain}" ) ) ) );
+	}
+}
 
 if( $current_blog->archived == '1' || $current_blog->spam == '1' ) {
-	header('HTTP/1.1 410 Gone');
-	graceful_fail(__('This blog has been archived or suspended.'));
+	if ( file_exists( WP_CONTENT_DIR . '/blog-suspended.php' ) ) {
+		require_once( WP_CONTENT_DIR . '/blog-suspended.php' );
+		die();
+	} else {
+		header('HTTP/1.1 410 Gone');
+		graceful_fail(__('This blog has been archived or suspended.'));
+	}
 }
 
 /**
  * Should be exactly the same as the default value of SECRET_KEY in wp-config-sample.php
- * @since 2.5
+ * @since 2.5.0
  */
 $wp_default_secret_key = 'put your unique phrase here';
-if( defined( 'SECRET_KEY' ) )
-	$wp_default_secret_key = SECRET_KEY;
 
 /**
  * It is possible to define this in wp-config.php
@@ -374,21 +598,21 @@ if ( !defined('PASS_COOKIE') )
 
 /**
  * It is possible to define this in wp-config.php
- * @since 2.5
+ * @since 2.5.0
  */
 if ( !defined('AUTH_COOKIE') )
 	define('AUTH_COOKIE', 'wordpress_' . COOKIEHASH);
 
 /**
  * It is possible to define this in wp-config.php
- * @since 2.6
+ * @since 2.6.0
  */
 if ( !defined('SECURE_AUTH_COOKIE') )
 	define('SECURE_AUTH_COOKIE', 'wordpress_sec_' . COOKIEHASH);
 
 /**
  * It is possible to define this in wp-config.php
- * @since 2.6
+ * @since 2.6.0
  */
 if ( !defined('LOGGED_IN_COOKIE') )
 	define('LOGGED_IN_COOKIE', 'wordpress_logged_in_' . COOKIEHASH);
@@ -416,7 +640,7 @@ if ( !defined('SITECOOKIEPATH') )
 
 /**
  * It is possible to define this in wp-config.php
- * @since 2.6
+ * @since 2.6.0
  */
 if ( !defined('ADMIN_COOKIE_PATH') ) {
 	if( constant( 'VHOST' ) == 'no' ) {
@@ -428,7 +652,7 @@ if ( !defined('ADMIN_COOKIE_PATH') ) {
 
 /**
  * It is possible to define this in wp-config.php
- * @since 2.6
+ * @since 2.6.0
  */
 if ( !defined('PLUGINS_COOKIE_PATH') )
 	define( 'PLUGINS_COOKIE_PATH', preg_replace('|https?://[^/]+|i', '', WP_PLUGIN_URL)  );
@@ -442,7 +666,7 @@ if ( !defined('COOKIE_DOMAIN') )
 
 /**
  * It is possible to define this in wp-config.php
- * @since 2.6
+ * @since 2.6.0
  */
 if ( !defined('FORCE_SSL_ADMIN') )
 	define('FORCE_SSL_ADMIN', false);
@@ -450,7 +674,7 @@ force_ssl_admin(FORCE_SSL_ADMIN);
 
 /**
  * It is possible to define this in wp-config.php
- * @since 2.6
+ * @since 2.6.0
  */
 if ( !defined('FORCE_SSL_LOGIN') )
 	define('FORCE_SSL_LOGIN', false);
@@ -462,20 +686,36 @@ force_ssl_login(FORCE_SSL_LOGIN);
  */
 if ( !defined( 'AUTOSAVE_INTERVAL' ) )
 	define( 'AUTOSAVE_INTERVAL', 60 );
-	
+
+/**
+ * It is possible to define this in wp-config.php
+ * @since 2.9.0
+ */
+if ( !defined( 'EMPTY_TRASH_DAYS' ) )
+	define( 'EMPTY_TRASH_DAYS', 30 );
 
 require (ABSPATH . WPINC . '/vars.php');
 
+// make taxonomies available to plugins and themes
+// @plugin authors: warning: this gets registered again on the init hook
+create_initial_taxonomies();
 
-if ( get_option('active_plugins') ) {
-	$current_plugins = get_option('active_plugins');
-	if ( is_array($current_plugins) ) {
-		foreach ($current_plugins as $plugin) {
-			if ( '' != $plugin && 0 == validate_file($plugin) && file_exists(WP_PLUGIN_DIR . '/' . $plugin) )
-				include_once(WP_PLUGIN_DIR . '/' . $plugin);
-		}
+$current_plugins = apply_filters( 'active_plugins', get_option( 'active_plugins' ) );
+if ( is_array($current_plugins) && !defined('WP_INSTALLING') ) {
+	foreach ( $current_plugins as $plugin ) {
+		// check the $plugin filename
+		// Validate plugin filename
+		if ( validate_file($plugin) // $plugin must validate as file
+			|| '.php' != substr($plugin, -4) // $plugin must end with '.php'
+			|| !file_exists(WP_PLUGIN_DIR . '/' . $plugin)	// $plugin must exist
+			)
+			continue;
+
+		include_once(WP_PLUGIN_DIR . '/' . $plugin);
 	}
+	unset($plugin);
 }
+unset($current_plugins);
 
 require (ABSPATH . WPINC . '/pluggable.php');
 
@@ -512,6 +752,9 @@ $_POST   = add_magic_quotes($_POST  );
 $_COOKIE = add_magic_quotes($_COOKIE);
 $_SERVER = add_magic_quotes($_SERVER);
 
+// Force REQUEST to be GET + POST.  If SERVER, COOKIE, or ENV are needed, use those superglobals directly.
+$_REQUEST = array_merge($_GET, $_POST);
+
 do_action('sanitize_comment_cookies');
 
 /**
@@ -543,17 +786,24 @@ $wp_rewrite   =& new WP_Rewrite();
  */
 $wp           =& new WP();
 
+/**
+ * WordPress Widget Factory Object
+ * @global object $wp_widget_factory
+ * @since 2.8.0
+ */
+$wp_widget_factory =& new WP_Widget_Factory();
+
 do_action('setup_theme');
 
 /**
  * Web Path to the current active template directory
- * @since 1.5
+ * @since 1.5.0
  */
 define('TEMPLATEPATH', get_template_directory());
 
 /**
  * Web Path to the current active template stylesheet directory
- * @since 2.1
+ * @since 2.1.0
  */
 define('STYLESHEETPATH', get_stylesheet_directory());
 
@@ -585,17 +835,8 @@ if ( TEMPLATEPATH !== STYLESHEETPATH && file_exists(STYLESHEETPATH . '/functions
 if ( file_exists(TEMPLATEPATH . '/functions.php') )
 	include(TEMPLATEPATH . '/functions.php');
 
-/**
- * shutdown_action_hook() - Runs just before PHP shuts down execution.
- *
- * @access private
- * @since 1.2
- */
-function shutdown_action_hook() {
-	do_action('shutdown');
-	wp_cache_close();
-}
-register_shutdown_function('shutdown_action_hook');
+// Load in support for template functions which the theme supports
+require_if_theme_supports( 'post-thumbnails', ABSPATH . WPINC . '/post-thumbnail-template.php' );
 
 $wp->init();  // Sets up current user.
 
